@@ -11,11 +11,6 @@ use My::Module::Recommend::All qw{ __all };
 my %misbehaving_os = map { $_ => 1 } qw{ MSWin32 cygwin };
 
 my @optionals = (
-    __any( 'Astro::Coord::ECI::TLE::Iridium'	=> <<'EOD' ),
-      This module is needed if you wish to compute Iridium Classic flare
-      events. If you do not intend to do this, this module is not
-      needed.
-EOD
     __any( 'Astro::SIMBAD::Client'	=> <<'EOD' ),
       This module is required for the 'satpass' script's 'sky lookup'
       command, but is otherwise unused by this package. If you do not
@@ -38,6 +33,14 @@ EOD
       you are running an earlier Perl, you can try installing Date-Manip
       5.54, which is the most recent version that does _not_ require
       Perl 5.10.
+EOD
+    __all( 'DateTime', 'DateTime::TimeZone'	=> <<'EOD' ),
+      If you set the 'zone' attribute of Astro::Coord::ECI::TLE::Iridium
+      to a zone name, these modules will be used to determine if a flare
+      occurred before or after midnight. If not available, $ENV{TZ} will
+      be set to the zone name in the hope that the localtime() built-in
+      will respond to this. If the 'zone' attribute is undef (the
+      default) or a numeric offset from GMT, this module is not used.
 EOD
     __any( 'Geo::Coder::OSM'			=> <<'EOD' ),
       This module is required for the 'satpass' script's 'geocode'
@@ -84,6 +87,63 @@ EOD
 EOD
 );
 
+sub make_optional_modules_tests {
+    eval {
+	require Test::Without::Module;
+	1;
+    } or return;
+    my $dir = 'xt/author/optionals';
+    -d $dir
+	or mkdir $dir
+	or die "Can not create $dir: $!\n";
+    opendir my $dh, 't'
+	or die "Can not access t/: $!\n";
+    while ( readdir $dh ) {
+	m/ \A [.] /smx
+	    and next;
+	m/ [.] t \z /smx
+	    or next;
+	my $fn = "$dir/$_";
+	-e $fn
+	    and next;
+	print "Creating $fn\n";
+	open my $fh, '>:encoding(utf-8)', $fn
+	    or die "Can not create $fn: $!\n";
+	print { $fh } <<"EOD";
+package main;
+
+use strict;
+use warnings;
+
+use Test::More 0.88;
+
+use lib qw{ inc };
+
+use My::Module::Recommend;
+
+BEGIN {
+    eval {
+	require Test::Without::Module;
+	Test::Without::Module->import(
+	    My::Module::Recommend->optionals() );
+	1;
+    } or plan skip_all => 'Test::Without::Module not available';
+}
+
+do 't/$_';
+
+1;
+
+__END__
+
+# ex: set textwidth=72 :
+EOD
+    }
+    closedir $dh;
+
+    return $dir;
+}
+
 sub optionals {
     return ( map { $_->modules() } @optionals );
 }
@@ -111,10 +171,6 @@ EOD
     return;
 }
 
-sub test_without {
-    return ( map { $_->test_without() } @optionals );
-}
-
 1;
 
 =head1 NAME
@@ -137,6 +193,24 @@ mechanism is not used because we find its output on the Draconian side.
 
 This class supports the following public methods:
 
+=head2 make_optional_modules_tests
+
+ My::Module::Recommend->make_optional_modules_tests()
+
+This static method creates the optional module tests. These are stub
+files in F<xt/author/optionals/> that use C<Test::Without::Module> to
+hide all the optional modules and then invoke the normal tests in F<t/>.
+The aim of these tests is to ensure that we get no test failures if the
+optional modules are missing.
+
+This method is idempotent; that is, it only creates the directory and
+the individual stub files if they are missing.
+
+On success this method returns the name of the optional tests directory.
+If C<Test::Without::Module> can not be loaded this method returns
+nothing. If the directory or any file can not be created, an exception
+is thrown.
+
 =head2 optionals
 
  say for My::Module::Recommend->optionals();
@@ -152,19 +226,10 @@ modules are installed. If any are not installed, a message is printed to
 standard error explaining the benefits to be gained from installing the
 module, and any possible problems with installing it.
 
-=head2 test_without
-
- say for My::Module::Recommend->test_without();
-
-This static method simply returns the names of the modules to be tested
-without.
-
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-satpass>,
-L<https://github.com/trwyant/perl-Astro-Coord-ECI/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -172,7 +237,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2024 by Thomas R. Wyant, III
+Copyright (C) 2014-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
